<!-- # IMSI Merge Request Template -->

<!-- Use "Draft" for in progress, remove for review and trigger CI -->

Closes:

Related Issues:


## Summary

<!--
Provide a brief and clean summary of what this MR does:
* What problem does it solve?
* Why is it needed?
* Which part of IMSI (or related tool) does it affect?
* Does this feature conflict with known future development or other systems?
-->


<!--
If this MR causes a config-breaking change:
* Include the heading below, and list the changes.
* Link to model repo MRs where this change is applied (update version requirements!)
-->
<!-- ### Config Breaking Changes**: -->


## Testing

<!--
Describe how this MR was tested:
* Confirm that unit tests pass
* Include steps to reproduce test cases (imsi commands, settings, etc)
* List imsi and repo versions
* Confirm BI model results when necessary (provide runid)
-->

<!-- v OPTIONAL, uncomment v -->
<!-- ### Missing test coverage -->
<!--
List new tests need to be written here. Explain why they are not included in this MR.
-->


## References

<!--
* Related documentation or configuration paths
-->


## Reviewers

<!-- Select at least one member as reviewer (who will mark this MR as "approved"): -->
**Functional Review**: @ras008 @rna001 @rrd001 @sts000

<!-- Select at least one member as merger (who will execute the merge after approval):-->
<!-- add @rna001 as a backup when needed-->
**Integration Approval**: @ncs001 @nil001
